#
# spec file for package cryptsetup
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cryptsetup
Url:            http://code.google.com/p/cryptsetup/
Version:        1.6.4
Release:        4.5
Summary:        Set Up dm-crypt Based Encrypted Block Devices
License:        SUSE-GPL-2.0-with-openssl-exception and LGPL-2.0+
Group:          System/Base

Source:         https://www.kernel.org/pub/linux/utils/cryptsetup/v1.6/cryptsetup-%{version}.tar.xz
# GPG signature of the uncompressed tarball.
Source1:        https://www.kernel.org/pub/linux/utils/cryptsetup/v1.6/cryptsetup-%{version}.tar.sign
Source2:        baselibs.conf
Source3:        %{name}.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  device-mapper-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  fipscheck
BuildRequires:  fipscheck-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libselinux-devel
BuildRequires:  libtool
# 2.6.38 has the required if_alg.h
BuildRequires:  linux-glibc-devel >= 2.6.38
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
Requires:       libfipscheck1

%description
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.

%package -n libcryptsetup4
Summary:        Set Up dm-crypt Based Encrypted Block Devices
Group:          System/Base

%description  -n libcryptsetup4
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.

%package -n libcryptsetup4-hmac
Summary:        Checksums for libcryptsetup4
Group:          System/Base

%description  -n libcryptsetup4-hmac
This package contains HMAC checksums for integrity checking of libcryptsetup4,
used for FIPS.

%package -n libcryptsetup-devel
Summary:        Set Up dm-crypt Based Encrypted Block Devices
Group:          Development/Libraries/C and C++
# cryptsetup-devel last used 11.1
Provides:       cryptsetup-devel = %{version}
Obsoletes:      cryptsetup-devel < %{version}
Requires:       glibc-devel
Requires:       libcryptsetup4 = %{version}

%description  -n libcryptsetup-devel
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.

%prep
%setup -q

%build
# cryptsetup build
%{?suse_update_config:%{suse_update_config}}
autoreconf -f -i
test -e po/Makevars || cp po/Makevars.template po/Makevars
%configure \
	    --disable-static --enable-shared \
	    --enable-cryptsetup-reencrypt \
	    --enable-selinux --enable-fips
make %{?_smp_mflags}

%install
# Generate HMAC checksums (FIPS)
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}} \
  %{__arch_install_post} \
  %{__os_install_post} \
  fipshmac %{buildroot}/%{_libdir}/libcryptsetup.so.* \
%{nil}

make install DESTDIR=$RPM_BUILD_ROOT
install -d -m 755 $RPM_BUILD_ROOT/sbin
ln -s ..%{_sbindir}/cryptsetup $RPM_BUILD_ROOT/sbin
# don't want this file in /lib (FHS compat check), and can't move it to /usr/lib
rm -f $RPM_BUILD_ROOT/%_libdir/*.la
#
%find_lang %name --all-name

%pre

%post
test -n "$FIRST_ARG" || FIRST_ARG="$1"
#
# convert noauto to nofail and turn on fsck (bnc#724113)
#
marker="/var/adm/crypsetup.fstab.noauto_converted"
if [ "$FIRST_ARG" -gt 1 -a ! -e "$marker" ]; then
	echo "updating /etc/fstab ... "
	tmpfstab="/etc/fstab.cryptsetup.$$"
	sed -e '/^\/dev\/mapper\/cr_.*,noauto\s/{s/,noauto\(\s\)/,nofail\1/;s/ 0 0$/ 0 2/}' < /etc/fstab > "$tmpfstab"
	if diff -u0 /etc/fstab "$tmpfstab"; then
		echo "no change"
		rm -f "$tmpfstab"
		> "$marker"
	else
		cp "$tmpfstab" "$marker"
		mv "$tmpfstab" /etc/fstab
	fi
fi

%post -n libcryptsetup4 -p /sbin/ldconfig

%postun -n libcryptsetup4 -p /sbin/ldconfig

%files -f %name.lang
%defattr(-,root,root)
#ghost %verify(not md5 size mtime) %config(noreplace,missingok) /etc/crypttab
#ghost %verify(not md5 size mtime) %config(noreplace,missingok) /etc/cryptotab
/sbin/cryptsetup
%{_sbindir}/cryptsetup
%{_sbindir}/veritysetup
%{_sbindir}/cryptsetup-reencrypt
%_mandir/man8/cryptsetup.8.gz
%_mandir/man8/cryptsetup-reencrypt.8.gz
%_mandir/man8/veritysetup.8.gz

%files -n libcryptsetup4
%defattr(-,root,root)
/%{_libdir}/libcryptsetup.so.4*

%files -n libcryptsetup4-hmac
%defattr(-,root,root)
/%{_libdir}/.libcryptsetup.so.4*hmac

%files -n libcryptsetup-devel
%defattr(-,root,root)
%_includedir/libcryptsetup.h
%{_libdir}/libcryptsetup.so
%{_libdir}/pkgconfig/*

%changelog
* Mon Aug 11 2014 meissner@suse.com
- libcryptsetup4-hmac split off contain the hmac for FIPS certification
* Tue May 27 2014 meissner@suse.com
- version 1.6.4
  - new tarball / signature location
  * Implement new erase (with alias luksErase) command.
  * Add internal "whirlpool_gcryptbug hash" for accessing flawed
    Whirlpool hash in gcrypt (requires gcrypt 1.6.1 or above).
  * Allow to use --disable-gcrypt-pbkdf2 during configuration
    to force use internal PBKDF2 code.
  * Require gcrypt 1.6.1 for imported implementation of PBKDF2
    (PBKDF2 in gcrypt 1.6.0 is too slow).
  * Add --keep-key to cryptsetup-reencrypt.
  * By default verify new passphrase in luksChangeKey and luksAddKey
    commands (if input is from terminal).
  * Fix memory leak in Nettle crypto backend.
  * Support --tries option even for TCRYPT devices in cryptsetup.
  * Support --allow-discards option even for TCRYPT devices.
    (Note that this could destroy hidden volume and it is not suggested
    by original TrueCrypt security model.)
  * Link against -lrt for clock_gettime to fix undefined reference
    to clock_gettime error (introduced in 1.6.2).
  * Fix misleading error message when some algorithms are not available.
  * Count system time in PBKDF2 benchmark if kernel returns no self
    usage info.
- enable fips mode
- build against fipscheck library
- generate hmac of libcryptsetup.so.4 for fips
* Wed Apr 23 2014 dmueller@suse.com
- remove dependency on gpg-offline (source_validator already
  checks for gpg integrity)
* Sun Dec 15 2013 crrodriguez@opensuse.org
- version 1.6.3
  * Fix cryptsetup reencryption tool to work properly
  with devices using 4kB sectors.
  * Rewrite cipher benchmark loop which was unreliable on very fast machines.
  * Support activation of old TrueCrypt containers (requires kernel 3.13)
  * Other bugfixes.
* Sun Aug  4 2013 crrodriguez@opensuse.org
- cryptsetup 1.6.2
  * Print error and fail if more device arguments
  are present for isLuks command.
  * Fix cipher specification string parsing
  (found by gcc -fsanitize=address option).
  * Try to map TCRYPT system encryption through partitions
  * Workaround for some recent changes in automake
* Tue Jul  2 2013 crrodriguez@opensuse.org
- cryptsetup 1.6.1
  * Fix loop-AES keyfile parsing.
  * Fix passphrase pool overflow for too long TCRYPT passphrase.
  * Fix deactivation of device when failed underlying node disappeared.
- There is a bug in the released tarball, due to HAVE_BYTESWAP_H
  and HAVE_ENDIAN_H not properly handled by the buildsystem. A
  patch with permanent solution was sent and accepted upstream
  and will appear in the next release, for now an spec file workaround
  is in place, remove in the next update.
* Sun Mar 24 2013 jengelh@inai.de
- Remove excessive dependencies of libcryptsetup-devel
  (it does not require any of these)
* Tue Jan 15 2013 lnussel@suse.de
- version 1.6.0
  * Change LUKS default cipher to to use XTS encryption mode,
  aes-xts-plain64 (i.e. using AES128-XTS).
  * license change to GPL-2.0+ from GPL-1.0
  * new unified command open and close.
  * direct support for TCRYPT (TrueCrypt and compatible tc-play) on-disk format
  * new benchmark command
* Thu Dec 13 2012 lnussel@suse.de
- version 1.5.1:
  * Added keyslot checker
  * Add crypt_keyslot_area() API call.
  * Optimize seek to keyfile-offset (Issue #135, thx to dreisner).
  * Fix luksHeaderBackup for very old v1.0 unaligned LUKS headers.
  * Allocate loop device late (only when real block device needed).
  * Rework underlying device/file access functions.
  * Create hash image if doesn't exist in veritysetup format.
  * Provide better error message if running as non-root user (device-mapper, loop).
* Wed Dec 12 2012 lnussel@suse.de
- split off hashalot and boot.crypto
- move to /usr
* Tue Nov 20 2012 sbrabec@suse.cz
- Verify GPG signature.
* Tue Sep 25 2012 fcrozat@suse.com
- Remove crypttab manpage, it is now provided by systemd.
* Wed Aug  1 2012 lnussel@suse.de
- version 1.5.0:
  * Add --device-size option for reencryption tool.
  * Switch to use unit suffix for --reduce-device-size option.
  * Remove open device debugging feature (no longer needed).
  * Introduce cryptsetup-reencrypt - experimental offline LUKS reencryption tool.
  * Fix luks-header-from-active script (do not use LUKS header on-disk, add UUID).
  * Add --test-passphrase option for luksOpen (check passphrase only).
  * Introduce veritysetup for dm-verity target management.
  * Both data and header device can now be a file.
  * Loop is automatically allocated in crypt_set_data_device().
  * Require only up to last keyslot area for header device (ignore data offset).
  * Fix header backup and restore to work on files with large data offset.
  * Fix readonly activation if underlying device is readonly (1.4.0).
  * Fix keyslot removal (wipe keyslot) for device with 4k hw block (1.4.0).
  * Allow empty cipher (cipher_null) for testing.
  * Fix loop mapping on readonly file.
  * Relax --shared test, allow mapping even for overlapping segments.
  * Support shared flag for LUKS devices (dangerous).
  * Switch on retry on device remove for libdevmapper.
  * Allow "private" activation (skip some udev global rules) flag.
* Mon Jul  9 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-openssl-exception and LGPL-2.0+
  cryptsetup developers use a special exception to link against openSSL
* Fri Jun 15 2012 lnussel@suse.de
- boot.crypto:
  * update man page to mention systemd and wiki article
  * sanitize dm target names (bnc#716240)
* Tue Apr 17 2012 lnussel@suse.de
- boot.crypto:
  * prefer physdev from crypttab
  * fix non-plymouth use
* Mon Apr 16 2012 lnussel@suse.de
- new version 1.4.2
  * Fix header check to support old (cryptsetup 1.0.0) header alignment. (1.4.0)
  * Add --keyfile-offset and --new-keyfile-offset parameters to API and CLI.
  * Add repair command and crypt_repair() for known LUKS metadata problems repair.
  * Allow to specify --align-payload only for luksFormat.
  * Unify password verification option.
  * Support password verification with quiet flag if possible. (1.2.0)
  * Fix retry if entered passphrases (with verify option) do not match.
  * Support UUID=<LUKS_UUID> format for device specification.
  * Add --master-key-file option to luksOpen (open using volume key).
  * Fix use of empty keyfile.
  * Fix error message for luksClose and detached LUKS header.
  * Allow --header for status command to get full info with detached header.
* Mon Apr 16 2012 lnussel@suse.de
- boot.crypto:
  * avoid warning about module 'kernel' (bnc#741468)
  * incorporate plymouth support
* Fri Dec 16 2011 jengelh@medozas.de
- Update to new upstream release 1.4.1
  * support for trim/discard
  * The on-disk LUKS header can now be detached (e.g. placed on
  separate device or in file)
  * Support key-slot option for luksOpen (use only explicit keyslot)
  * API: Removal of deprecated API from libcryptsetup (all functions
  using struct crypt_options)
* Thu Oct 27 2011 lnussel@suse.de
- on update convert noauto to nofail and turn on fsck (bnc#724113)
* Mon Oct 10 2011 jeffm@suse.com
- cryptsetup-boot: Rescan LVM volumes after opening crypto (bnc#722916).
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri May 27 2011 lnussel@suse.de
- boot.crypto:
  * don't hard require boot.device-mapper in boot.crypto
* Wed May 25 2011 lnussel@suse.de
- new version 1.3.1:
  * Fix keyfile=- processing in create command (regression in 1.3.0).
  * Simplify device path status check (use /sys and do not scan /dev).
  * Do not ignore device size argument for create command (regression in 1.2.0).
  * Fix error paths in blockwise code and lseek_write call.
* Mon Apr 11 2011 lnussel@suse.de
- new version 1.3.0:
  * userspace crypto backends support
  * Cryptsetup now automatically allocates loopback device
  if device argument is file and not plain device.
  * luksChangeKey command
  * loopaesOpen command for loop-AES compatibility
* Thu Feb 17 2011 lnussel@suse.de
- boot.crypto:
  * also fix exit code in boot.crypto.functions (bnc#671822)
* Mon Jan 31 2011 lnussel@suse.de
- boot.crypto:
  * don't fail if loop module is not loaded
  * adapt to new crypsetup exit codes (bnc#667931)
* Mon Dec 20 2010 lnussel@suse.de
- new version 1.2.0
  * Add selection of random/urandom number generator for luksFormat
  (option --use-random and --use-urandom).
  * Fix luksRemoveKey to not ask for remaining keyslot passphrase,
  only for removed one.
  * No longer support luksDelKey (replaced with luksKillSlot).
  * if you want to remove particular passphrase, use luksKeyRemove
  * if you want to remove particular keyslot, use luksKillSlot
  Note that in batch mode luksKillSlot allows removing of any keyslot
  without question, in normal mode requires passphrase or keyfile from
  other keyslot.
  * Default alignment for device (if not overridden by topology info)
  is now (multiple of) *1MiB*.
  This reflects trends in storage technologies and aligns to the same
  defaults for partitions and volume management.
  * Allow explicit UUID setting in luksFormat and allow change it later
  in luksUUID (--uuid parameter).
  * All commands using key file now allows limited read from keyfile using
  - -keyfile-size and --new-keyfile-size parameters (in bytes).
  This change also disallows overloading of --key-size parameter which
  is now exclusively used for key size specification (in bits.)
  * luksFormat using pre-generated master key now properly allows
  using key file (only passphrase was allowed prior to this update).
  * Add --dump-master-key option for luksDump to perform volume (master)
  key dump. Note that printed information allows accessing device without
  passphrase so it must be stored encrypted.
  This operation is useful for simple Key Escrow function (volume key and
  encryption parameters printed on paper on safe place).
  This operation requires passphrase or key file.
  * The reload command is no longer supported.
  (Use dmsetup reload instead if needed. There is no real use for this
  function except explicit data corruption:-)
  * Cryptsetup now properly checks if underlying device is in use and
  disallows *luksFormat*, luksOpen and create commands on open
  (e.g. already mapped or mounted) device.
  * Option --non-exclusive (already deprecated) is removed.
  Libcryptsetup API additions:
  * new functions
  * crypt_get_type() - explicit query to crypt device context type
  * crypt_resize() - new resize command using context
  * crypt_keyslot_max() - helper to get number of supported keyslots
  * crypt_get_active_device() - get active device info
  * crypt_set/get_rng_type() - random/urandom RNG setting
  * crypt_set_uuid() - explicit UUID change of existing device
  * crypt_get_device_name() - get underlying device name
  * Fix optional password callback handling.
  * Allow to activate by internally cached volume key immediately after
  crypt_format() without active slot (for temporary devices with
  on-disk metadata)
  * libcryptsetup is binary compatible with 1.1.x release and still
  supports legacy API calls
  * cryptsetup binary now uses only new API calls.
  * Static compilation of both library (--enable-static) and cryptsetup
  binary (--enable-static-cryptsetup) is now properly implemented by common
  libtool logic.
  Prior to this it produced miscompiled dynamic cryptsetup binary with
  statically linked libcryptsetup.
  The static binary is compiled as src/cryptsetup.static in parallel
  with dynamic build if requested.
* Tue Nov 30 2010 lnussel@suse.de
- boot.crypto:
  * drop cryptotab support
* Tue Nov 16 2010 lnussel@suse.de
- boot.crypto:
  * add a few tweaks for systemd (bnc#652767)
* Wed Jul  7 2010 lnussel@suse.de
- new version 1.1.3
  * Fix device alignment ioctl calls parameters. (Device alignment
    code was not working properly on some architectures like ppc64.)
  * Fix activate_by_* API calls to handle NULL device name as
    documented. (To enable check of passphrase/keyfile using
    libcryptsetup without activating the device.)
  * Fix udev support for old libdevmapper with not compatible definition.
  * Added Polish translation file.
* Thu Jul  1 2010 lnussel@suse.de
- skip temporary mappings in early stage as chmod needs to be called
  on the mounted file systems (bnc#591704)
* Sat Jun 26 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon May 31 2010 lnussel@suse.de
- new version 1.1.2 fixes keyfile regression introduced by 1.1.1
  * Fix luksFormat/luksOpen reading passphrase from stdin and "-" keyfile.
  * Support --key-file/-d option for luksFormat.
  * Fix description of --key-file and add --verbose and --debug options to man page.
  * Add verbose log level and move unlocking message there.
  * Remove device even if underlying device disappeared (remove, luksClose).
  * Fix (deprecated) reload device command to accept new device argument.
* Tue May 25 2010 lnussel@suse.de
- new version 1.1.1
  * Detects and use device-mapper udev support if available.
  * Supports device topology detection for data alignment.
  * Fix luksOpen reading of passphrase on stdin (if "-" keyfile specified).
  * Fix isLuks to initialise crypto backend (blkid instead is suggested anyway).
  * Properly initialise crypto backend in header backup/restore commands.
  * Do not verify unlocking passphrase in luksAddKey command.
  * Allow no hash specification in plain device constructor - user can provide volume key directly.
  * Try to use pkgconfig for device mapper library in configuration script.
  * Add some compatibility checks and disable LUKS suspend/resume if not supported.
  * Rearrange tests, "make check" now run all available test for package.
  * Avoid class C++ keyword in library header.
* Tue Mar  9 2010 lnussel@suse.de
- boot.crypto:
  * turn off splash only if needed to avoid flicker
* Tue Mar  2 2010 lnussel@suse.de
- boot.crypto:
  * restore splash screen state after initrd prompt (bnc#559053)
  * use highlighted prompt in initrd too
  * fix adding volumes with initrd option (bnc#558891)
* Tue Feb  2 2010 lnussel@suse.de
- boot.crypto:
  * document the stages of the boot process
  * show status message in boot.cypto-early
  * don't perform some checks if the device is skipped anyways
  * seed random number generator (bnc#575139)
* Mon Jan 18 2010 lnussel@suse.de
- cryptsetup 1.1.0:
  * IMPORTANT: the default compiled-in cipher parameters changed
  plain mode: aes-cbc-essiv:sha256 (default is backward incompatible!).
  LUKS mode: aes-cbc-essiv:sha256 (only key size increased)
  In both modes is now default key size 256bits.
  * Default compiled-in parameters are now configurable through configure options:
  - -with-plain-* / --with-luks1-* (see configure --help)
  * If you need backward compatible defaults for distribution use
  configure --with-plain-mode=cbc-plain --with-luks1-keybits=128
  Default compiled-in modes are printed in "cryptsetup --help" output.
  * Change in iterations count (LUKS):
  The slot and key digest iteration minimum count is now 1000.
  The key digest iteration count is calculated from iteration time (approx 1/8 of req. time).
  For more info about above items see discussion here: http://tinyurl.com/yaug97y
  * New libcryptsetup API (documented in libcryptsetup.h).
  The old API (using crypt_options struct) is still available but will remain
  frozen and not used for new functions.
  Soname of library changed to libcryptsetup.so.1.0.0.
  (But only recompilation should be needed for old programs.)
  The new API provides much more flexible operation over LUKS device for
  applications, it is preferred that new applications will use libcryptsetup
  and not wrapper around cryptsetup binary.
  * New luksHeaderBackup and luksHeaderRestore commands.
  These commands allows binary backup of LUKS header.
  Please read man page about possible security issues with backup files.
  * New luksSuspend (freeze device and wipe key) and luksResume (with provided passphrase).
  luksSuspend wipe encryption key in kernel memory and set device to suspend
  (blocking all IO) state. This option can be used for situations when you need
  temporary wipe encryption key (like suspend to RAM etc.)
  Please read man page for more information.
  * New --master-key-file option for luksFormat and luksAddKey.
  User can now specify pre-generated master key in file, which allows regenerating
  LUKS header or add key with only master key knowledge.
  * Uses libgcrypt and enables all gcrypt hash algorithms for LUKS through -h luksFormat option.
  Please note that using different hash for LUKS header make device incompatible with
  old cryptsetup releases.
  * Introduces --debug parameter.
  Use when reporting bugs (just run cryptsetup with --debug and attach output
  to issue report.) Sensitive data are never printed to this log.
  * Moves command successful messages to verbose level.
  * Requires device-mapper library and libgcrypt to build.
  * Uses dm-uuid for all crypt devices, contains device type and name now.
  * Removes support for dangerous non-exclusive option
  (it is ignored now, LUKS device must be always opened exclusive)
- boot.crypto:
  * don't use dirty prompt override hack anymore
  * wait for volume groups if resume volume is on lvm (bnc#556895)
  * dynamically determine whether the cryptomgr module is neeeded
* Mon Oct 19 2009 lnussel@suse.de
- add luks script in volumemanager stage too, this way some side
  effects are avoided (bnc#547612)
* Wed Oct  7 2009 lnussel@suse.de
- boot.crypto:
  * /lib/udev/vol_id no longer exists, use blkid instead
  * add space at end of password prompt in initrd
  * fix autodetetection of root on LVM on LUKS (bnc#528474)
* Tue Oct  6 2009 lnussel@suse.de
- boot.crypto: more changes as agreed with the Debian maintainer:
  * rename keyscript variable CRYPTTAB_DEVICE to CRYPTTAB_SOURCE
  * export list of options in CRYPTTAB_OPTIONS
* Tue Sep 29 2009 lnussel@suse.de
- replace patch that quits on EOF with upstream version
* Fri Sep 25 2009 lnussel@suse.de
- actually hash=plain can be used to get raw keyscript output so
  remove keyscript_raw again
* Thu Sep 24 2009 lnussel@suse.de
- boot.crypto:
  * don't use hashalot if keyfile is specified
  * to comply with Debian, keyscripts must only output the password.
    In order to allow keyscript to use different methods to retrieve
    a key, add a keyscript_rawkey option.
- cryptsetup:
  * When reading no single byte for the key abort.
* Mon Sep 21 2009 lnussel@suse.de
- boot.crypto:
  * fix test for keyfile (bnc#540363)
* Wed Sep 16 2009 lnussel@suse.de
- boot.crypto:
  * 2.6.31 requires the cryptomgr module in the initrd (bnc#535013)
* Tue Sep 15 2009 lnussel@suse.de
- boot.crypto:
  * uppercase variables exported to keyscript in anticipation of
    Debian adopting the implementation
* Fri Sep  4 2009 lnussel@suse.de
- boot.crypto:
  * fix setting options without parameter
  * infinite retries in initrd
  * tries=0 means infinite tries
  * implement retries in the script to make it work with keyscripts and non-luks volumes
  * keyscript support (fate#302628)
  * remove the option to fsck the fs as it actually never worked
  * fix initrd option parsing
* Thu Aug 27 2009 lnussel@suse.de
- new cryptsetup version 1.0.7
  * Allow removal of last slot in luksRemoveKey and luksKillSlot.
  * Reject unsupported --offset and --skip options for luksFormat and update man page.
  * Various man page fixes.
  * Set UUID in device-mapper for LUKS devices.
  * Retain readahead of underlying device.
  * Display device name when asking for password.
  * Check device size when loading LUKS header. Remove misleading error message later.
  * Add error hint if dm-crypt mapping failed.
  * Use better error messages if device doesn't exist or is already used by other mapping.
  * Fix make distcheck.
  * Check if all slots are full during luksAddKey.
  * Fix segfault in set_error.
  * Code cleanups, remove precompiled pot files, remove unnecessary files from po directory
  * Fix uninitialized return value variable in setup.c.
  * Code cleanups. (thanks to Ivan Stankovic)
  * Fix wrong output for remaining key at key deletion.
  * Allow deletion of key slot while other keys have the same key information.
  * Add missing AM_PROG_CC_C_O to configure.in
  * Remove duplicate sentence in man page.
  * Wipe start of device (possible fs signature) before LUKS-formatting.
  * Do not process configure.in in hidden directories.
  * Return more descriptive error in case of IO or header format error.
  * Use remapping to error target instead of calling udevsettle for temporary crypt device.
  * Check device mapper communication and warn user if device-mapper support missing in kernel.
  * Fix signal handler to properly close device.
  * write_lseek_blockwise: declare innerCount outside the if block.
  * add -Wall to the default CFLAGS. fix some signedness issues.
  * Error handling improvement.
  * Add non-exclusive override to interface definition.
  * Refactor key slot selection into keyslot_from_option.
* Wed Aug 19 2009 lnussel@suse.de
- boot.crypto:
  * set infinite timeout during 2nd stage (bnc#456004)
* Mon Jul 13 2009 lnussel@suse.de
- boot.crypto:
  * wait for device before calling luksOpen (bnc#521446)
* Wed Jun 17 2009 coolo@novell.com
- fix link order
* Thu Jun 11 2009 coolo@novell.com
- fix compile with glibc 2.10
* Thu Apr  2 2009 lnussel@suse.de
- boot.crypto:
  * resolve symlinks when searching for loop devices (bnc#490170)
  * add extra man page tags to avoid FIXME output of docbook
  * don't pipe password if there's only one device to open
  * update copyright information
  * fix spelling and actually stop in pre_stop_hook
  * introduce initrd option in crypttab (bnc#465711)
* Fri Mar  6 2009 lnussel@suse.de
- boot.crypto:
  * print dm name instead of physdev (bnc#456664)
  * make prompt work with infinite timeout (bnc#466405)
  * implement pre-stop hook (bnc#481870)
  * remove hardcoded loop device number limit (bnc#481872)
  * Warn if using a non-absolute path for physdev in crypttab
- hashalot: compute hash of empty passphrase if not interactive
  (bnc#475135)
* Tue Mar  3 2009 lnussel@suse.de
- fix boot.crypto doesn't care on tries flag in crypttab (bnc#480741)
- mkinitrd scripts now included in boot.crypto git
* Thu Feb 26 2009 mhopf@suse.de
- Fix segfault with oversized hashes (bnc #476290).
* Wed Feb 25 2009 jsmeix@suse.de
- Fixed initrd LUKS password annoyance in mkinitrd-boot.sh and
  mkinitrd-setup.sh when the same password is used for all
  partitions. In this case the password is now only asked
  once (bnc#465711).
* Sun Dec 14 2008 bwalle@suse.de
- Fix LUKS root partition residing on a soft raid (bnc#358341)
* Mon Nov  3 2008 mkoenig@suse.de
- boot.crypto-early: explicitly start before boot.localfs
* Fri Sep 12 2008 mkoenig@suse.de
- branch off shlib to subpackage libcryptsetup0
- rename cryptsetup-devel to libcryptsetup-devel
* Wed Sep  3 2008 hare@suse.de
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Wed Aug 20 2008 mkoenig@suse.de
- enable SELinux support (fate#303662)
* Wed Aug 13 2008 mkoenig@suse.de
- boot.crypto:
  * Fix init script tags
* Fri Aug  8 2008 mkoenig@suse.de
- boot.crypto:
  * Provide some reasonable exit status (bnc#409502)
* Wed Jul 23 2008 hare@suse.de
- Include mkinitrd scriptlets.
* Wed Jul 23 2008 mkoenig@suse.de
- use /sbin/udevadm settle instead of /sbin/udevsettle (bnc#404875)
* Tue May  6 2008 mkoenig@suse.de
- load loop module in boot.crypto-early as it might be needed.
  It is previously initially loaded by boot.localfs.
* Wed Apr  9 2008 mkoenig@suse.de
- add support for boot.crypto-early (bnc#355824)
  needed to encrypt block devices for usage with LVM or MD
  adds a new option 'noearly' for crypttab, which will skip
  the device in boot.crypto-early.
* Wed Feb 27 2008 mkoenig@suse.de
- update to svn revision 46:
  * fix out of bound for key index in delKey (bnc#360041)
  * Add typo fixes to the cryptsetup.8 manpage
  * Add key-slot patch
  * Remove O_EXCL requirement for certain LUKS operations
  * mention luksKillSlot in the manpage
* Mon Feb  4 2008 lnussel@suse.de
- boot.crypto:
  * check for columns of terminal (bnc#337614)
  * enhance crypttab manpage (bnc#351061)
  * check for fs_passno (bnc#345339)
* Wed Jan  9 2008 lnussel@suse.de
- upgrade to svn revision 42 which includes previous patches
- boot.crypto:
  * don't mount read-only as safety check (bnc#345338)
  * implement precheck scripts
  * allow restarting of single volumes (bnc#345605)
  * status query of individual devices (bnc#345605)
  * add vol_id check script
  * maintain boot.crypto stuff in revision control and use tarball
    snapshots of it
* Thu Nov 29 2007 lnussel@suse.de
- upgrade to svn revision 38
* Wed Nov  7 2007 mkoenig@suse.de
- add %%fillup_prereq and %%insserv_prereq to PreReq
* Tue Oct 16 2007 lnussel@suse.de
- upgrade to svn revision 31
  * Rename luksDelKey into luksKillSlot
  * Add luksRemoveKey that queries a given key before removal
  * Fix segfault in luksOpen.
  * Add LUKS_device_ready check for most LUKS calls, so that
    cryptsetup dies before password querying in case a blockdev is
    unavailable
  * For LUKS key material access require exclusive access to the
    underlying device. This will prevent multiple mappings onto a
    single LUKS device. dm*crypt doesn't feature any syncing
    capabilities, hence there is no real application for this as it
    will likely lead to disk corruption.
  * Add signal handler to keyencryption to free the temporary
    mapping in case the user hits ctrl-c.
* Mon Aug 27 2007 lnussel@suse.de
- remove /var/run/keymap from previous boot to make /etc/init.d/kbd
  work (#296409)
* Mon Aug 27 2007 lnussel@suse.de
- run fsck with progressbar (#304750)
* Thu Jun 21 2007 mkoenig@suse.de
- run udevsettle to avoid problems with busy temporary
  device mapper devices [#285478]
* Mon Jun 11 2007 lnussel@suse.de
- rephrase error message (#279169)
* Fri Jun  1 2007 lnussel@suse.de
- rename util-linux-crypto to cryptsetup
- remove dmconvert
- replace svn snapshot with official 1.0.5 release
- don't enable boot.crypto by default
* Tue May 29 2007 lnussel@suse.de
- fix segfault when trying to open a non existing device
- fix gcc warnings
- add Short-Description to boot.crypto
- use %%find_lang
* Wed May  9 2007 lnussel@suse.de
- boot.crypto: implement 'status'
- boot.crypto: accept argument to start/stop single devices
* Wed May  9 2007 lnussel@suse.de
- hashalot: add timeout option
* Wed May  9 2007 lnussel@suse.de
- fix build
* Tue May  8 2007 lnussel@suse.de
- boot.crypto: switch off splash screen only when needed
- boot.crypto: report status for individual volumes instead of using one global
  exit status
- hashalot: exit unsucessfully on empty passphrase
* Tue May  8 2007 lnussel@suse.de
- boot.crypto: sleep a bit longer before overwriting the prompt
- boot.crypto: add support for pseed and itercountk options
- boot.crypto: skip entries with unsupported/unknown options
- hashalot: add support for itercountk
* Fri May  4 2007 lnussel@suse.de
- upgrade cryptsetup to current svn revision 30 which includes
  previous patches.
- fix background prompt process not getting killed on ctrl-d in
  boot.crypto
* Fri Apr 27 2007 lnussel@suse.de
- upgrade cryptsetup to current svn revision 26. Does no longer hang
  when a file is specified instead of a device.
- remove obsolete cryptsetup.sh script
- boot.crypto:
  * drop support for cryptoloop, use cryptsetup also for cryptotab
  * refactor code and create reusable components for use in cryptotab
    and crypttab code path
  * run sulogin only during boot if fsck failed
  * support crypttab's 'tries' option
- add crypttab manpage based on Debian one
* Tue Apr 24 2007 lnussel@suse.de
- add boot.crypto (#257884)
- add crypttab and cryptotab as %%ghost to filelist
* Tue Mar 27 2007 mkoenig@suse.de
- move devel .so link to %%{libdir}
- run ldconfig, since we have now a shared lib installed
* Fri Mar 23 2007 dmueller@suse.de
- cryptsetup can now link shared since libpopt is
  no longer under /usr
* Fri Mar  9 2007 lnussel@suse.de
- add patch to support old loop_fish2 key hash method
* Thu Dec  7 2006 mkoenig@suse.de
- update cryptsetup to version 1.0.4:
  * added terminal timeout rewrite
  * allow user selection of key slot
  * reading binary keys from stdin using the "-" as key file
  * fix 64 bit compiler warning issues.
  * fix getline problem for 64-bit archs.
* Fri Oct 13 2006 mkoenig@suse.de
- fix build failure due to missing pthreads
* Wed Sep 13 2006 hvogel@suse.de
- use the LUKS version of cryptsetup
- split -devel subpackage for libcryptsetup
- remove patches because they are in the new cryptsetup
  * cryptsetup-0.1-static.patch
  * cryptsetup-0.1-retval.patch
  * cryptsetup-0.1-dmi.exists.patch
  * cryptsetup-0.1-timeout.patch
- use man page from the new cryptsetup
* Tue May 16 2006 hvogel@suse.de
- Fix cryptsetup to work when the device does not exist yet
  [#175931]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 mmj@suse.de
- Remove symlinks to hashalot we don't want
* Thu Oct 13 2005 hvogel@suse.de
- Fix uninitialized var in dmconvert. Add
  * dmconvert-0.2-uninitialized.patch
- Fix return value in cryptsetup. Add
  * cryptsetup-0.1-retval.patch
* Wed Jun 29 2005 hvogel@suse.de
- Link cryptsetup static so it can be in /sbin and you can get
  /usr over nfs or even crypted
* Mon May  9 2005 hvogel@suse.de
- New package, Version 2.12q
